/***************************************************************************
 *   Copyright (C) 2018 by Nicolas Carion                                  *
 *   This file is part of Kdenlive. See www.kdenlive.org.                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3 or any later version accepted by the       *
 *   membership of KDE e.V. (or its successor approved  by the membership  *
 *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
 *   version 3 of the license.                                             *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#pragma once

#include <QObject>

/** @brief Provides an interface to the clipboard, to use directly from QML
    Inspired by https://stackoverflow.com/questions/40092352/passing-qclipboard-to-qml
 */

class ClipboardProxy : public QObject
{
    Q_OBJECT
    Q_PROPERTY(QStringList mimeTypes READ mimeTypes NOTIFY changed)
public:
    explicit ClipboardProxy(QObject *parent);

    QStringList mimeTypes() const;

signals:
    void changed();
};
